use std::io::Read;

use anyhow::Context;
use clap::{Parser, Subcommand};
use copy::LocalCopierState;
use state::State;

mod copy;
mod state;

#[derive(Parser)]
#[command(author, version, about, long_about = None, subcommand_required = true)]
struct Command {
    #[command(subcommand)]
    command: Option<Commands>,
}

#[derive(Subcommand)]
enum Commands {
    Listen {},
    Copy {},
    Remote {
        #[command(subcommand)]
        command: RemoteCommands,
    },
}

#[derive(Subcommand)]
enum RemoteCommands {
    Copy {},
}

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    dotenv::dotenv().ok();
    tracing_subscriber::fmt::init();

    let cli = Command::parse();
    tracing::debug!("Starting cli");

    let state = State::new();

    match cli.command.unwrap() {
        Commands::Listen {} => {}
        Commands::Copy {} => {
            let mut input = String::new();
            std::io::stdin()
                .read_to_string(&mut input)
                .context("failed to read from stdin")?;

            if input.is_empty() {
                tracing::info!("no content to put in clipboard");
                return Ok(());
            }

            tracing::debug!(content = &input, "found content");
            state.local_copier().copy(input.as_bytes()).await?;
        }
        Commands::Remote { command } => match command {
            RemoteCommands::Copy {} => todo!(),
        },
        _ => (),
    }

    Ok(())
}
